"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.watch = exports.readJournalDir = void 0;
const fs = __importStar(require("fs"));
const _ = __importStar(require("lodash"));
const path = __importStar(require("path"));
const sane_1 = __importDefault(require("sane"));
/** Scans a dir for log files, executing the callbackFn on each line. Returns the latest logfile */
function readJournalDir(dir, callbackFn) {
    return new Promise((resolve, reject) => {
        fs.readdir(dir, (err, items) => {
            if (err) {
                console.error(err);
                reject(err);
            }
            const logFiles = items.filter(name => path.extname(name) === '.log');
            if (_.isEmpty(logFiles)) {
                reject(`Unable to read any log files in ${dir}`);
            }
            for (const logfile of logFiles) {
                fs.readFileSync(dir + '/' + logfile, 'utf-8')
                    .split('\n')
                    .forEach(line => callbackFn(line));
            }
            resolve(dir + '/' + logFiles[logFiles.length - 1]);
        });
    });
}
exports.readJournalDir = readJournalDir;
/** Start watching a dir for new .log files */
function watch(dir, callbackFn) {
    const watcher = sane_1.default(dir, {
        glob: ['**/*.log']
    });
    watcher.on('add', (filepath, root) => {
        if (path.extname(filepath) === '.log') {
            callbackFn(path.normalize(`${root}/${filepath}`));
        }
    });
    return watcher;
}
exports.watch = watch;
//# sourceMappingURL=journal-files.js.map