/// <reference types="node" />
import { EventEmitter } from 'events';
export declare interface Journal {
    /**
     * Emitted on a journal log event.
     * obj: Event payload
     * historical: true if the event is from a pre-existing file when `scan({ fromBegninning: true })` is called
     */
    on(eventType: string, callback: (obj: any, historical: boolean) => void): this;
}
export declare class Journal extends EventEmitter {
    private tail?;
    private watcher?;
    /** Scan a journal dir and start tailing it for new events */
    scan({ fromBeginning, dir }: ScanOptions, onFinishedFromBeginning?: () => void): Promise<void>;
    startWatching(file: string, opts?: object): void;
    readJournalLine(data: string, backfill?: boolean): void;
    stop(done?: () => void): void;
}
/** Extra options for scanning */
export interface ScanOptions {
    /** Read all journal files from the beginning. Defaults to false */
    fromBeginning?: boolean;
    /** Optional override path to journal directory */
    dir?: string;
}
