"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Journal = void 0;
const events_1 = require("events");
const os_1 = require("os");
const path = __importStar(require("path"));
const tail_1 = require("tail");
const journal_files_1 = require("./journal-files");
const journalDir = path.normalize(os_1.homedir() + '/Saved Games/Frontier Developments/Elite Dangerous');
class Journal extends events_1.EventEmitter {
    constructor() {
        super(...arguments);
        this.tail = undefined;
        this.watcher = undefined;
    }
    /** Scan a journal dir and start tailing it for new events */
    scan({ fromBeginning = false, dir = journalDir }, onFinishedFromBeginning = () => { return; }) {
        return __awaiter(this, void 0, void 0, function* () {
            const watchFileOpts = { useWatchFile: true, fromBeginning: false };
            const readDir = yield journal_files_1.readJournalDir(dir, (line) => this.readJournalLine(line, fromBeginning));
            this.watcher = journal_files_1.watch(dir, (newPath) => this.startWatching(newPath, Object.assign(Object.assign({}, watchFileOpts), { fromBeginning: true })));
            this.startWatching(readDir, Object.assign({}, watchFileOpts));
            onFinishedFromBeginning();
            return Promise.resolve();
        });
    }
    startWatching(file, opts) {
        if (this.tail) {
            this.tail.unwatch();
        }
        this.tail = new tail_1.Tail(file, opts);
        this.tail.watch();
        this.tail.on('line', data => this.readJournalLine(data, false));
    }
    readJournalLine(data, backfill = false) {
        try {
            if (data) {
                const obj = JSON.parse(data);
                const timestamp = new Date(obj.timestamp);
                this.emit('*', Object.assign(Object.assign({}, obj), { timestamp }), backfill);
                this.emit(obj.event, Object.assign(Object.assign({}, obj), { timestamp }), backfill);
            }
        }
        catch (e) {
            console.error(`Problem with line ${data}`, e);
        }
    }
    stop(done) {
        this.removeAllListeners();
        if (this.tail) {
            this.tail.unwatch();
        }
        if (this.watcher) {
            this.watcher.close(done);
        }
    }
}
exports.Journal = Journal;
//# sourceMappingURL=journal.js.map